import AppNavbar from './components/AppNavbar.js';
import Home from './pages/Home.js';
import Products from './pages/Products.js';
import SearchProducts from './components/SearchProducts.js';
import Register from './pages/Register.js';
import Login from './pages/Login.js';
import Logout from './pages/Logout.js';
import Profile from './pages/Profile.js';
import AddProduct from './components/AddProduct.js';
import Error from './pages/Error.js';
import ProductView from './pages/ProductView.js';
import OrderHistory from './pages/OrderHistory.js';
import MyCart from './pages/MyCart.js';

import styles from './App.global.css';
import AOS from 'aos';
import 'aos/dist/aos.css';


import {useState, useEffect} from 'react';
import {UserProvider} from "./UserContext.js";
import {BrowserRouter as Router, Route, Routes} from 'react-router-dom';


function App() {

  const [user, setUser] = useState({
    id: null,
    isAdmin: null
  })

  
  const unSetUser = () => {
    setUser({
       id: null,
       isAdmin: null
     });
    
    localStorage.clear();
  }


  useEffect(()=>{

    fetch(`${process.env.REACT_APP_API_BASE_URL}/users/details`, {
       method: "GET",
       headers: {
            Authorization : `Bearer ${localStorage.getItem('token')}`
       } 
    })
    .then(result => result.json())
    .then(data => {
        if(typeof data._id !== "undefined"){
            setUser({
              id: data._id,
              isAdmin: data.isAdmin
            })
        }else{
          setUser({
            id: null,
            isAdmin: null
          })
        }

    })

  }, [])

  return (
  <UserProvider value = {{user, setUser, unSetUser}}>
    <Router>
      <AppNavbar/>  
      <Routes>
        <Route path = "/" element = {<Home/>}/>
        <Route path = "/products" element = {<Products/>}/>
        <Route path = "/products/search" element = {<SearchProducts/>}/>
        <Route path = "/register" element = {<Register/>}/>
        <Route path = "/login" element = {<Login/>}/>
        <Route path = "/logout" element = {<Logout/>}/>
        <Route path = "/profile" element = {<Profile/>} />

        <Route path = "*" element={<Error/>} />

        <Route path = "/products/create" element = {<AddProduct/>}/>

        <Route path = "/products/:productId" element = {<ProductView/>}/>
        <Route path = "/orders" element = {<OrderHistory/>}/>
        <Route path = "/my-cart" element = {<MyCart/>}/>

      </Routes>
    </Router>
  </UserProvider>

  );
}

export default App;
