import {Navigate} from "react-router-dom";
import {Button, Form, Container, Col, Row} from 'react-bootstrap';
import {useState, useEffect, useContext, useRef} from 'react';

import Swal from 'sweetalert2';

import UserContext from '../UserContext.js';

export default function AddProduct(){
	const [name, setName] = useState("");
	const [description, setDescription] = useState("");
	const [price, setPrice] = useState("");
	const [inventory, setInventory] = useState("");
	const [selectedImage, setSelectedImage] = useState(null);

	const inputFile = useRef(null);

	const [isActive, setIsActive] = useState(true);

	const {user} = useContext(UserContext);

	useEffect(()=>{
			if(name !== "" && description !== "" && price !== "" && inventory !== ""){
				setIsActive(false);
			}else{
				setIsActive(true);
			}

		}, [name, description, price, inventory]);

	async function addProduct(event){
		event.preventDefault();

		if (await isProductExisting()) {

				Swal.fire({
				    title: "Unsuccessful Product Creation!",
				    icon: "error",
				    text: 'Product already existing!'
				})

		} else {

			if (inventory <= 0 || price <= 0) {
			  Swal.fire({
			    title: "ERROR",
			    icon: "error",
			    text: "Invalid value input! Please enter a valid value."
			  });
			} else {

				const formData = new FormData();
				     formData.append('name', name);
				     formData.append('price', price);
				     formData.append('description', description);
				     formData.append('inventory', inventory);
				     if (selectedImage) {
				       formData.append('image', selectedImage);
				     }

			fetch(`${process.env.REACT_APP_API_BASE_URL}/products/create`, {
				method: 'POST',
				headers: {
					'Authorization': `Bearer ${user.token}`,
				},
				body: formData,
			})
			.then(result => result.json())
			.then(data => {
				if(data){
	                            Swal.fire({
	                                title: `${name} Added to products`,
	                                icon: "success",
	                                text: 'Add more products!'
	                            })

	                            setName('');
	                            setDescription('');
	                            setPrice('');
	                            setInventory('');

	                            if (inputFile.current) {
	                                        inputFile.current.value = "";
	                                        inputFile.current.type = "text";
	                                        inputFile.current.type = "file";
	                                    }
	                            setSelectedImage(null);
	                            
	                        } else {
	                            Swal.fire({
	                                title: "Unsuccessful Product Creation!",
	                                icon: "error",
	                                text: 'Please try again!'
	                            })
	                        }
			})
			}
		}

	}

	async function isProductExisting()  {
		const findProduct = await fetch(`${process.env.REACT_APP_API_BASE_URL}/products/check-product-existence`, {
			method: 'POST',
			headers: {
				"Content-Type" : "application/json",
				"Authorization" : `Bearer ${user.token}`,
			},
			body: JSON.stringify({
				productName: name
			})
		})

		const result = await findProduct.json();

		return result;
		
	}
	

	  const handleImageChange = (e) => {
	    const file = e.target.files[0];
	    setSelectedImage(file);
	  };

		return(
			(user.isAdmin !== true) ?
			<Navigate to="/products" />
			:

			<Container>
				<Row>
					<h1 className = "text-center my-5 headers">Create Product:</h1>
					<Col className = "col-4 mx-auto mb-3 create-product-form">
						<Form onSubmit= {event => addProduct(event)} className = "p-2">
							{/*Form Group for Name*/}
							<Form.Group className="mb-3" controlId="name">
						       <Form.Label>Product Name</Form.Label>
						       <Form.Control 
						       		type="text" 
						       		placeholder="Enter Name"
						       		required
						       		value = {name}
						       		onChange = {event => {
						       			setName(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*FormGroup for Description*/}
						     <Form.Group className="mb-3" controlId="description">
						       <Form.Label>Product Description</Form.Label>
						       <Form.Control 
						       		type="text" 
						       		placeholder="Enter Description" 
						       		required
						       		as="textarea" 
						       		rows={7}
						       		value = {description}
						       		onChange = {event => {
						       			setDescription(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*Form Group for Price*/}
						     <Form.Group className="mb-3" controlId="price">
						       <Form.Label>Price</Form.Label>
						       <Form.Control 
						       		type="number" 
						       		placeholder="Enter Price" 
						       		required
						       		value = {price}
						       		onChange = {event => {
						       			setPrice(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*Form Group for Inventory*/}
						     <Form.Group className="mb-3" controlId="inventory">
						       <Form.Label>Starting Inventory</Form.Label>
						       <Form.Control 
						       		type="number" 
						       		placeholder="Enter starting inventory" 
						       		required
						       		value = {inventory}
						       		onChange = {event => {
						       			setInventory(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     <div className = "p-3 col-12 mx-auto d-flex justify-content-around boxes">
						     <input type="file" accept="image/*" onChange={handleImageChange} ref={inputFile} />

						     <Button disabled = {isActive} className = "btn-submit nes-btn" type="submit">
						       Submit
						     </Button>
						     </div>




						   </Form>

					</Col>
				</Row>
			</Container>
			)
}