import { useState, useEffect, useContext } from 'react';
import Swal from 'sweetalert2';
import {useNavigate} from "react-router-dom";

import ProfileContext from "../pages/ProfileContext.js";

const ResetPassword = () => {
  const [newPassword, setNewPassword] = useState('');
  const [confirmPassword, setConfirmPassword] = useState('');
  const [message, setMessage] = useState(null);

  const [isDisabled, setIsDisabled] = useState(true);
  const navigate = useNavigate();

  const { setIsVisibleChangePW } = useContext(ProfileContext);

  useEffect(() => {
        if(newPassword.length === 0 || confirmPassword === 0){
          setIsDisabled(true);
        }else{
          setIsDisabled(false);
        }

    }, [confirmPassword, newPassword])

  const handleResetPassword = async () => {
    // Check if passwords match
    if (newPassword !== confirmPassword) {
      setMessage('Passwords do not match.');
      return;
    }

    const token = localStorage.getItem("token");

    try {
      const response = await fetch(`${process.env.REACT_APP_API_BASE_URL}/users/reset-password`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          Authorization: `Bearer ${token}`,
        },
        body: JSON.stringify({ newPassword }),
      });

      if (response.ok) {
        Swal.fire({
          title: "Change password successful",
          icon: "success",
        })
        navigate("/");
      } else {
        const errorData = await response.json();
        setMessage(`Error: ${errorData.message}`);
      }
    } catch (error) {
      console.error('Error resetting password:', error);
      setMessage('An unexpected error occurred.');
    }
  };

  return (
    <div className="container p-5 forms d-flex flex-column align-items-center">
      <h2>Change Password</h2>
      <div className="form-group col-6">
        <label>New Password:</label>
        <input
          type="password"
          className="form-control"
          value={newPassword}
          onChange={(e) => setNewPassword(e.target.value)}
        />
      </div>
      <div className="form-group col-6">
        <label>Confirm Password:</label>
        <input
          type="password"
          className="form-control"
          value={confirmPassword}
          onChange={(e) => setConfirmPassword(e.target.value)}
        />
      </div>
      {message && <div className="alert alert-info">{message}</div>}
      
      <div className="container col-8 mt-3 d-flex justify-content-around">
        <button
          type="button"
          className="btn btn-submit nes-btn"
          disabled = {isDisabled}
          onClick={() => {
            handleResetPassword();
            setIsVisibleChangePW(false)
          }}
        >
          Change
        </button>
        {message && <div className="mt-3">{message}</div>}

        <button
          type="button"
          className="btn btn-submit nes-btn"
          onClick={() => setIsVisibleChangePW(false)}
        >
          Cancel
        </button>
      </div>
    </div>
  );
};

export default ResetPassword;
