    import {React, useState, useEffect, useContext, useRef } from 'react';
    import { Container, Row, Col, Button } from 'react-bootstrap';

    import UserContext from "../UserContext.js";

    import { Navigate } from 'react-router-dom';

    import ResetPassword from '../components/ResetPassword.js'
    import UpdateProfile from '../components/UpdateProfile.js'

    import AOS from 'aos';

    import {ProfileProvider} from "./ProfileContext.js";
    
export default function Profile() {
    const [firstName, setFirstName] = useState('');
    const [lastName, setLastName] = useState('');
    const [email, setEmail] = useState('');
    const [mobileNo, setMobileNo] = useState('');

    const { user } = useContext(UserContext);

    // useRef for update button (not used)
    const updateButtonRef = useRef(null);
    const chngPWButtonRef = useRef(null);

    // Profile button states
    const [isVisibleUpdateBox, setIsVisibleUpdateBox] = useState(false);
    const [isVisibleChangePW, setIsVisibleChangePW] = useState(false);

    useEffect(() => {
        getProfile();
        AOS.init();
    }, []);

    const fetchProfile = () => {
        getProfile();
    }

    async function getProfile() {
        try {
            const response = await fetch(`${process.env.REACT_APP_API_BASE_URL}/users/details`, {
                    method: 'GET',
                    headers: {
                    'Authorization': `Bearer ${user.token}`,
                }
            });

            if (!response.ok) {
                throw new Error('Error fetching profile');
            }

            const data = await response.json();

            setFirstName(data.firstName);
            setLastName(data.lastName);
            setEmail(data.email);
            setMobileNo(data.mobileNo);
        } catch (error) {
            console.error('Error fetching profile:', error.message);
        }
    }

return (
<ProfileProvider value = {{isVisibleUpdateBox, setIsVisibleUpdateBox, isVisibleChangePW, setIsVisibleChangePW }}>
{
    (user.id === null) ?
    <Navigate to="/products" />
    :
    <>
    <Container className="fs-4" data-aos="zoom-in-up">

        <Row>
            <Col className="p-5 my-5 profile-box">
                <h1 className = "headers">PROFILE</h1>
                <h2  className = "headers fs-4">{firstName} {lastName}</h2>
                <h3>Contacts</h3>
                <ul>
                    <li>
                        <strong>Email:</strong> {email}
                    </li>
                    <li>
                        <strong>Phone Number:</strong> {mobileNo}
                    </li>
                </ul>

                <div className = "col-4 d-flex justify-content-around">
                    <Button className = "fs-5 btn-dash nes-btn" ref={updateButtonRef}
                     onClick = {() => {
                        setIsVisibleUpdateBox(true);
                        // updateButtonRef.current.disabled = true;
                    }}>
                        Update Profile
                    </Button>
                    <Button className = "fs-5 btn-dash nes-btn" ref={chngPWButtonRef}
                    onClick = {() => {
                        setIsVisibleChangePW(true);
                        // chngPWButtonRef.current.disabled = true;
                    }}>
                        Change Password
                    </Button>

                </div>

            </Col>

        </Row>

    </Container>

    <Container className="fs-3 my-5 d-flex flex-row align-items-start">

            {/*Update Profile Box*/}
            { isVisibleUpdateBox &&
            <Col className = "col-5 my-5 mx-5" data-aos="zoom-in-up">
                <UpdateProfile fetchProfile = {fetchProfile} />
            </Col>
            }

            {/*Change PW Box*/}
            { isVisibleChangePW &&
            <Col className = "col-5 my-5 mx-5" data-aos="zoom-in-up">
                <ResetPassword/>
            </Col>
            }
    </Container>

    </>
}
</ProfileProvider>
);

}
