import {Navigate, useNavigate} from "react-router-dom";
import {Button, Form, Container, Col, Row} from 'react-bootstrap';
import {useState, useEffect, useContext} from 'react';
import Swal from 'sweetalert2';

import UserContext from '../UserContext.js';

export default function Register(){
	const [firstName, setFirstName] = useState("");
	const [lastName, setLastName] = useState("");
	const [email, setEmail] = useState("");
	const [mobileNo, setMobileNo] = useState("");
	const [password, setPassword] = useState("");
	const [confirmPassword, setConfirmPassword] = useState("");

	const [isActive, setIsActive] = useState(true);
	const navigate = useNavigate();

	const {user} = useContext(UserContext);

	useEffect(()=>{
			if(firstName !== "" && lastName !== "" && email !== "" && mobileNo !=="" && password !== "" && confirmPassword !== "" && password === confirmPassword){
				setIsActive(false);
			}else{
				setIsActive(true);
			}

		}, [firstName, lastName, email, mobileNo, password, confirmPassword]);

	function registerUser(event){
		event.preventDefault();

		fetch(`${process.env.REACT_APP_API_BASE_URL}/users/register`, {
			method: 'POST',
			headers: {
				"Content-Type" : "application/json"
			},
			body: JSON.stringify({
				firstName: firstName,
				lastName: lastName,
				email: email,
				password: password,
				mobileNo: mobileNo
			})
		})
		.then(result => result.json())
		.then(data => {
			if(data){
				Swal.fire({
					title: "Thank you for registering",
					icon: "success",
				})

				setFirstName('');
				setLastName('');
				setEmail('');
				setMobileNo('');
				setPassword('');
				setConfirmPassword('');

				navigate("/login");

			}else{
				Swal.fire({
					title: "Register Unsuccessful",
					icon: "error",
					text: "Please try again!"
				})
			}
		})

	}


		if (user.id !== null) {

		return (
			<Navigate to = "/" />

			)

		}else{

		return(
			<Container>
				<Row>
					<h1 className = "text-center">Register</h1>
					<Col className = "col-4 mx-auto mb-3 forms">
						<Form onSubmit= {event => registerUser(event)} className = "p-2">
							{/*Form Group for First Name*/}
							<Form.Group className="mb-3" controlId="firstName">
						       <Form.Label>First Name</Form.Label>
						       <Form.Control 
						       		type="text" 
						       		placeholder="First name"
						       		required
						       		value = {firstName}
						       		onChange = {event => {
						       			setFirstName(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*FormGroup for Last Name*/}
						     <Form.Group className="mb-3" controlId="lastName">
						       <Form.Label>Last Name</Form.Label>
						       <Form.Control 
						       		type="text" 
						       		placeholder="Last name" 
						       		required
						       		value = {lastName}
						       		onChange = {event => {
						       			setLastName(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*Form Group for email*/}
						     <Form.Group className="mb-3" controlId="formBasicEmail">
						       <Form.Label>Email address</Form.Label>
						       <Form.Control 
						       		type="email" 
						       		placeholder="Enter email" 
						       		required
						       		value = {email}
						       		onChange = {event => {
						       			setEmail(event.target.value);
						       		}}
						       		/>
						       <Form.Text className="text-muted">
						         We'll never share your email with anyone else.
						       </Form.Text>
						     </Form.Group>

						     {/*FormGroup for Mobile Num*/}
						     <Form.Group className="mb-3" controlId="mobileNo">
						       <Form.Label>Mobile Number</Form.Label>
						       <Form.Control 
						       		type="number" 
						       		placeholder="Mobile Number" 
						       		required
						       		value = {mobileNo}
						       		onChange = {event => {
						       			setMobileNo(event.target.value)
						       		}}
						       		/>
						     </Form.Group>


						     {/*FormGroup for password*/}
						     <Form.Group className="mb-3" controlId="formBasicPassword1">
						       <Form.Label>Password</Form.Label>
						       <Form.Control 
						       		type="password" 
						       		placeholder="Password" 
						       		required
						       		value ={password}
						       		onChange = {event => {
						       			setPassword(event.target.value);
						       		}}
						       		/>
						     </Form.Group>

						     {/*form group for confirmation of pw*/}
						     <Form.Group className="mb-3" controlId="formBasicPassword2">
						       <Form.Label>Confirm Password</Form.Label>
						       <Form.Control 
						       		type="password" 
						       		placeholder="Confirm your Password" 
						       		required
						       		value = {confirmPassword}
						       		onChange = {event => {
						       			setConfirmPassword(event.target.value)
						       		}}
						       		/>
						     </Form.Group>



						     <Button disabled = {isActive} className="btn-submit nes-btn" type="submit">
						       Submit
						     </Button>




						   </Form>

					</Col>
				</Row>
			</Container>
			)
		}
}